public inbox for linux-gpio@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH 0/2] Add support for additional AD717X models
@ 2024-01-15 13:53 Dumitru Ceclan
  2024-01-15 13:53 ` [PATCH 1/2] dt-bindings: adc: ad7173: add support for additional models Dumitru Ceclan
  2024-01-15 13:53 ` [PATCH 2/2] iio: " Dumitru Ceclan
  0 siblings, 2 replies; 5+ messages in thread
From: Dumitru Ceclan @ 2024-01-15 13:53 UTC (permalink / raw)
  Cc: linus.walleij, brgl, andy, linux-gpio, Lars-Peter Clausen,
	Jonathan Cameron, Rob Herring, Krzysztof Kozlowski, Conor Dooley,
	Andy Shevchenko, Arnd Bergmann, ChiaEn Wu, Niklas Schnelle,
	Leonard Göhrs, Mike Looijmans, Haibo Chen, Hugo Villeneuve,
	Ceclan Dumitru, linux-iio, devicetree, linux-kernel,
	Dumitru Ceclan

This patch series adds support for the Analog Devices AD7172-2, AD7175-8,
 AD7177-2 ADCs within the AD7173 driver.

 Datasheets:
 https://www.analog.com/media/en/technical-documentation/data-sheets/AD7172-4.pdf
 https://www.analog.com/media/en/technical-documentation/data-sheets/AD7175-8.pdf
 https://www.analog.com/media/en/technical-documentation/data-sheets/AD7177-2.pdf

Dumitru Ceclan (2):
  dt-bindings: adc: ad7173: add support for additional models
  iio: adc: ad7173: add support for additional models

 .../bindings/iio/adc/adi,ad7173.yaml          | 50 +++++++++++-
 drivers/iio/adc/ad7173.c                      | 76 +++++++++++++++++--
 2 files changed, 115 insertions(+), 11 deletions(-)

-- 
2.42.0


^ permalink raw reply	[flat|nested] 5+ messages in thread

* [PATCH 1/2] dt-bindings: adc: ad7173: add support for additional models
  2024-01-15 13:53 [PATCH 0/2] Add support for additional AD717X models Dumitru Ceclan
@ 2024-01-15 13:53 ` Dumitru Ceclan
  2024-01-15 16:10   ` Conor Dooley
  2024-01-15 13:53 ` [PATCH 2/2] iio: " Dumitru Ceclan
  1 sibling, 1 reply; 5+ messages in thread
From: Dumitru Ceclan @ 2024-01-15 13:53 UTC (permalink / raw)
  Cc: linus.walleij, brgl, andy, linux-gpio, Lars-Peter Clausen,
	Jonathan Cameron, Rob Herring, Krzysztof Kozlowski, Conor Dooley,
	Andy Shevchenko, Arnd Bergmann, ChiaEn Wu, Niklas Schnelle,
	Leonard Göhrs, Mike Looijmans, Haibo Chen, Hugo Villeneuve,
	Ceclan Dumitru, linux-iio, devicetree, linux-kernel,
	Dumitru Ceclan

Add support for: AD7172-2, AD7175-8, AD7177-2
Add hardware description of the AD771X family instead of "Bindings for"
AD7172-4 does not feature an internal reference, check for ext-ref

Signed-off-by: Dumitru Ceclan <mitrutzceclan@gmail.com>
---
 .../bindings/iio/adc/adi,ad7173.yaml          | 50 +++++++++++++++++--
 1 file changed, 46 insertions(+), 4 deletions(-)

diff --git a/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml b/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml
index 7c8caef76528..6d4b26e43144 100644
--- a/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml
+++ b/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml
@@ -11,19 +11,33 @@ maintainers:
   - Ceclan Dumitru <dumitru.ceclan@analog.com>
 
 description: |
-  Bindings for the Analog Devices AD717X ADC's. Datasheets for supported chips:
+  Analog Devices AD717X ADC's:
+  The AD717x family offer a complete integrated Sigma-Delta ADC solution which
+  can be used in high precision, low noise single channel applications
+  (Life Science measurements) or higher speed multiplexed applications
+  (Factory Automation PLC Input modules). The Sigma-Delta ADC is intended
+  primarily for measurement of signals close to DC but also delivers outstanding
+  performance with input bandwidths out to ~10kHz.
+
+  Datasheets for supported chips:
     https://www.analog.com/media/en/technical-documentation/data-sheets/AD7172-2.pdf
+    https://www.analog.com/media/en/technical-documentation/data-sheets/AD7172-4.pdf
     https://www.analog.com/media/en/technical-documentation/data-sheets/AD7173-8.pdf
     https://www.analog.com/media/en/technical-documentation/data-sheets/AD7175-2.pdf
+    https://www.analog.com/media/en/technical-documentation/data-sheets/AD7175-8.pdf
     https://www.analog.com/media/en/technical-documentation/data-sheets/AD7176-2.pdf
+    https://www.analog.com/media/en/technical-documentation/data-sheets/AD7177-2.pdf
 
 properties:
   compatible:
     enum:
       - adi,ad7172-2
+      - adi,ad7172-4
       - adi,ad7173-8
       - adi,ad7175-2
+      - adi,ad7175-8
       - adi,ad7176-2
+      - adi,ad7177-2
 
   reg:
     maxItems: 1
@@ -89,8 +103,10 @@ patternProperties:
           refout-avss: REFOUT/AVSS (Internal reference)
           avdd       : AVDD
 
-          External reference refin2 only available on ad7173-8.
-          If not specified, internal reference used.
+          External reference refin2 only available on ad7173-8 and ad7172-4.
+          Internal reference refout-avss not available on ad7172-4.
+
+          If not specified, internal reference used (if available).
         $ref: /schemas/types.yaml#/definitions/string
         enum:
           - refin
@@ -111,12 +127,15 @@ required:
 allOf:
   - $ref: /schemas/spi/spi-peripheral-props.yaml#
 
+  # Only ad7172-4 and ad7173-8 support refin2
   - if:
       properties:
         compatible:
           not:
             contains:
-              const: adi,ad7173-8
+              anyOf:
+                - const: adi,ad7172-4
+                - const: adi,ad7173-8
     then:
       properties:
         refin2-supply: false
@@ -129,6 +148,29 @@ allOf:
                 - refout-avss
                 - avdd
 
+  # Model ad7172-4 does not support internal reference
+  #  mandatory to have an external reference
+  - if:
+      properties:
+        compatible:
+          contains:
+            const: adi,ad7172-4
+    then:
+      patternProperties:
+        "^channel@[0-9a-f]$":
+          properties:
+            adi,reference-select:
+              enum:
+                - refin
+                - refin2
+                - avdd
+              default: false
+          required:
+            - adi,reference-select
+      oneOf:
+        - required: [refin2-supply]
+        - required: [refin-supply]
+
 unevaluatedProperties: false
 
 examples:
-- 
2.42.0


^ permalink raw reply related	[flat|nested] 5+ messages in thread

* [PATCH 2/2] iio: adc: ad7173: add support for additional models
  2024-01-15 13:53 [PATCH 0/2] Add support for additional AD717X models Dumitru Ceclan
  2024-01-15 13:53 ` [PATCH 1/2] dt-bindings: adc: ad7173: add support for additional models Dumitru Ceclan
@ 2024-01-15 13:53 ` Dumitru Ceclan
  2024-01-15 19:52   ` Andy Shevchenko
  1 sibling, 1 reply; 5+ messages in thread
From: Dumitru Ceclan @ 2024-01-15 13:53 UTC (permalink / raw)
  Cc: linus.walleij, brgl, andy, linux-gpio, Lars-Peter Clausen,
	Jonathan Cameron, Rob Herring, Krzysztof Kozlowski, Conor Dooley,
	Andy Shevchenko, Arnd Bergmann, ChiaEn Wu, Niklas Schnelle,
	Leonard Göhrs, Mike Looijmans, Haibo Chen, Hugo Villeneuve,
	Ceclan Dumitru, linux-iio, devicetree, linux-kernel,
	Dumitru Ceclan

Add support for Analog Devices AD7172-2, AD7175-8, AD7177-2

Signed-off-by: Dumitru Ceclan <mitrutzceclan@gmail.com>
---
 drivers/iio/adc/ad7173.c | 76 ++++++++++++++++++++++++++++++++++++----
 1 file changed, 69 insertions(+), 7 deletions(-)

diff --git a/drivers/iio/adc/ad7173.c b/drivers/iio/adc/ad7173.c
index 7a7e8262f189..8ca9871cc9cb 100644
--- a/drivers/iio/adc/ad7173.c
+++ b/drivers/iio/adc/ad7173.c
@@ -1,6 +1,10 @@
 // SPDX-License-Identifier: GPL-2.0+
 /*
  * AD7172-2/AD7173-8/AD7175-2/AD7176-2 SPI ADC driver
  * Copyright (C) 2015, 2023 Analog Devices, Inc.
  */
 
@@ -59,10 +63,13 @@
 #define AD7173_AIN_TEMP_POS	17
 #define AD7173_AIN_TEMP_NEG	18
 
-#define AD7172_ID			0x00d0
+#define AD7172_2_ID			0x00d0
+#define AD7172_4_ID			0x2050
 #define AD7173_ID			0x30d0
-#define AD7175_ID			0x0cd0
+#define AD7175_2_ID			0x0cd0
+#define AD7175_8_ID			0x3cd0
 #define AD7176_ID			0x0c90
+#define AD7177_ID			0x4fd0
 #define AD7173_ID_MASK			GENMASK(15, 4)
 
 #define AD7173_ADC_MODE_REF_EN		BIT(15)
@@ -104,15 +111,19 @@
 #define AD7173_SETUP_REF_SEL_EXT_REF	0x0
 #define AD7173_VOLTAGE_INT_REF_uV	2500000
 #define AD7173_TEMP_SENSIIVITY_uV_per_C	477
+#define AD7177_ODR_START_VALUE		0x07
 
 #define AD7173_FILTER_ODR0_MASK		GENMASK(5, 0)
 #define AD7173_MAX_CONFIGS		8
 
 enum ad7173_ids {
 	ID_AD7172_2,
+	ID_AD7172_4,
 	ID_AD7173_8,
 	ID_AD7175_2,
+	ID_AD7175_8,
 	ID_AD7176_2,
+	ID_AD7177_2,
 };
 
 struct ad7173_device_info {
@@ -182,7 +193,7 @@ static const unsigned int ad7175_sinc5_data_rates[] = {
 static const struct ad7173_device_info ad7173_device_info[] = {
 	[ID_AD7172_2] = {
 		.name = "ad7172-2",
-		.id = AD7172_ID,
+		.id = AD7172_2_ID,
 		.num_inputs = 5,
 		.num_channels = 4,
 		.num_configs = 4,
@@ -192,6 +203,17 @@ static const struct ad7173_device_info ad7173_device_info[] = {
 		.sinc5_data_rates = ad7173_sinc5_data_rates,
 		.num_sinc5_data_rates = ARRAY_SIZE(ad7173_sinc5_data_rates),
 	},
+	[ID_AD7172_4] = {
+		.id = AD7172_4_ID,
+		.num_inputs = 9,
+		.num_channels = 8,
+		.num_configs = 8,
+		.num_gpios = 4,
+		.has_temp = false,
+		.clock = 2 * HZ_PER_MHZ,
+		.sinc5_data_rates = ad7173_sinc5_data_rates,
+		.num_sinc5_data_rates = ARRAY_SIZE(ad7173_sinc5_data_rates),
+	},
 	[ID_AD7173_8] = {
 		.name = "ad7173-8",
 		.id = AD7173_ID,
@@ -206,7 +228,7 @@ static const struct ad7173_device_info ad7173_device_info[] = {
 	},
 	[ID_AD7175_2] = {
 		.name = "ad7175-2",
-		.id = AD7175_ID,
+		.id = AD7175_2_ID,
 		.num_inputs = 5,
 		.num_channels = 4,
 		.num_configs = 4,
@@ -216,6 +238,17 @@ static const struct ad7173_device_info ad7173_device_info[] = {
 		.sinc5_data_rates = ad7175_sinc5_data_rates,
 		.num_sinc5_data_rates = ARRAY_SIZE(ad7175_sinc5_data_rates),
 	},
+	[ID_AD7175_8] = {
+		.id = AD7175_8_ID,
+		.num_inputs = 17,
+		.num_channels = 16,
+		.num_configs = 8,
+		.num_gpios = 4,
+		.has_temp = true,
+		.clock = 16 * HZ_PER_MHZ,
+		.sinc5_data_rates = ad7175_sinc5_data_rates,
+		.num_sinc5_data_rates = ARRAY_SIZE(ad7175_sinc5_data_rates),
+	},
 	[ID_AD7176_2] = {
 		.name = "ad7176-2",
 		.id = AD7176_ID,
@@ -228,6 +261,17 @@ static const struct ad7173_device_info ad7173_device_info[] = {
 		.sinc5_data_rates = ad7175_sinc5_data_rates,
 		.num_sinc5_data_rates = ARRAY_SIZE(ad7175_sinc5_data_rates),
 	},
+	[ID_AD7177_2] = {
+		.id = AD7177_ID,
+		.num_inputs = 5,
+		.num_channels = 4,
+		.num_configs = 4,
+		.num_gpios = 2,
+		.has_temp = true,
+		.clock = 16 * HZ_PER_MHZ,
+		.sinc5_data_rates = ad7175_sinc5_data_rates,
+		.num_sinc5_data_rates = ARRAY_SIZE(ad7175_sinc5_data_rates),
+	},
 };
 
 static const char *const ad7173_ref_sel_str[] = {
@@ -636,7 +680,10 @@ static int ad7173_write_raw(struct iio_dev *indio_dev,
 	switch (info) {
 	case IIO_CHAN_INFO_SAMP_FREQ:
 		freq = val * MILLI + val2 / MILLI;
-		for (i = 0; i < st->info->num_sinc5_data_rates - 1; i++)
+		//AD7177-2 has the filter values [0-6] marked as reserved
+		// datasheet page 58
+		i = (st->info->id == AD7177_ID) ? AD7177_ODR_START_VALUE : 0;
+		for (; i < st->info->num_sinc5_data_rates - 1; i++)
 			if (freq >= st->info->sinc5_data_rates[i])
 				break;
 
@@ -844,8 +891,14 @@ static int ad7173_fw_parse_channel_config(struct iio_dev *indio_dev)
 		else
 			ref_sel = ret;
 
+		if (ref_sel == AD7173_SETUP_REF_SEL_INT_REF &&
+		    st->info->id == AD7172_2_ID){
+			fwnode_handle_put(child);
+			return dev_err_probe(dev, -EINVAL, "Internal reference is not available on ad7172-2\n");
+		}
+
 		if (ref_sel == AD7173_SETUP_REF_SEL_EXT_REF2 &&
-		    st->info->id != AD7173_ID) {
+		    st->info->id != AD7173_ID && st->info->id != AD7172_2_ID) {
 			fwnode_handle_put(child);
 			return dev_err_probe(dev, -EINVAL, "External reference 2 is only available on ad7173-8\n");
 		}
@@ -939,21 +992,30 @@ static int ad7173_probe(struct spi_device *spi)
 static const struct of_device_id ad7173_of_match[] = {
 	{ .compatible = "adi,ad7172-2",
 	  .data = &ad7173_device_info[ID_AD7172_2]},
+	{ .compatible = "adi,ad7172-4",
+	  .data = &ad7173_device_info[ID_AD7172_4]},
 	{ .compatible = "adi,ad7173-8",
 	  .data = &ad7173_device_info[ID_AD7173_8]},
 	{ .compatible = "adi,ad7175-2",
 	  .data = &ad7173_device_info[ID_AD7175_2]},
+	{ .compatible = "adi,ad7175-8",
+	  .data = &ad7173_device_info[ID_AD7175_8]},
 	{ .compatible = "adi,ad7176-2",
 	  .data = &ad7173_device_info[ID_AD7176_2]},
+	{ .compatible = "adi,ad7177-2",
+	  .data = &ad7173_device_info[ID_AD7177_2]},
 	{ }
 };
 MODULE_DEVICE_TABLE(of, ad7173_of_match);
 
 static const struct spi_device_id ad7173_id_table[] = {
 	{ "ad7172-2", (kernel_ulong_t)&ad7173_device_info[ID_AD7172_2]},
+	{ "ad7172-4", (kernel_ulong_t)&ad7173_device_info[ID_AD7172_4] },
 	{ "ad7173-8", (kernel_ulong_t)&ad7173_device_info[ID_AD7173_8]},
 	{ "ad7175-2", (kernel_ulong_t)&ad7173_device_info[ID_AD7175_2]},
+	{ "ad7175-8", (kernel_ulong_t)&ad7173_device_info[ID_AD7175_8]},
 	{ "ad7176-2", (kernel_ulong_t)&ad7173_device_info[ID_AD7176_2]},
+	{ "ad7177-2", (kernel_ulong_t)&ad7173_device_info[ID_AD7177_2]},
 	{ }
 };
 MODULE_DEVICE_TABLE(spi, ad7173_id_table);
@@ -1,6 +1,10 @@
 // SPDX-License-Identifier: GPL-2.0+
 /*
- * AD7172-2/AD7173-8/AD7175-2/AD7176-2 SPI ADC driver
+ * AD717X family SPI ADC driver
+ *
+ * Suported devices:
+ *  AD7172-2 AD7172-4 AD7173-8 AD7175-2 AD7175-8 AD7176-2 AD7177-2
+ *
  * Copyright (C) 2015, 2023 Analog Devices, Inc.
  */
-- 
2.42.0


^ permalink raw reply related	[flat|nested] 5+ messages in thread

* Re: [PATCH 1/2] dt-bindings: adc: ad7173: add support for additional models
  2024-01-15 13:53 ` [PATCH 1/2] dt-bindings: adc: ad7173: add support for additional models Dumitru Ceclan
@ 2024-01-15 16:10   ` Conor Dooley
  0 siblings, 0 replies; 5+ messages in thread
From: Conor Dooley @ 2024-01-15 16:10 UTC (permalink / raw)
  To: Dumitru Ceclan
  Cc: linus.walleij, brgl, andy, linux-gpio, Lars-Peter Clausen,
	Jonathan Cameron, Rob Herring, Krzysztof Kozlowski, Conor Dooley,
	Andy Shevchenko, Arnd Bergmann, ChiaEn Wu, Niklas Schnelle,
	Leonard Göhrs, Mike Looijmans, Haibo Chen, Hugo Villeneuve,
	Ceclan Dumitru, linux-iio, devicetree, linux-kernel

[-- Attachment #1: Type: text/plain, Size: 4546 bytes --]

On Mon, Jan 15, 2024 at 03:53:04PM +0200, Dumitru Ceclan wrote:
> Add support for: AD7172-2, AD7175-8, AD7177-2
> Add hardware description of the AD771X family instead of "Bindings for"
> AD7172-4 does not feature an internal reference, check for ext-ref
> 
> Signed-off-by: Dumitru Ceclan <mitrutzceclan@gmail.com>
> ---
>  .../bindings/iio/adc/adi,ad7173.yaml          | 50 +++++++++++++++++--
>  1 file changed, 46 insertions(+), 4 deletions(-)
> 
> diff --git a/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml b/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml
> index 7c8caef76528..6d4b26e43144 100644
> --- a/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml
> +++ b/Documentation/devicetree/bindings/iio/adc/adi,ad7173.yaml
> @@ -11,19 +11,33 @@ maintainers:
>    - Ceclan Dumitru <dumitru.ceclan@analog.com>
>  
>  description: |
> -  Bindings for the Analog Devices AD717X ADC's. Datasheets for supported chips:
> +  Analog Devices AD717X ADC's:
> +  The AD717x family offer a complete integrated Sigma-Delta ADC solution which
> +  can be used in high precision, low noise single channel applications
> +  (Life Science measurements) or higher speed multiplexed applications
> +  (Factory Automation PLC Input modules). The Sigma-Delta ADC is intended
> +  primarily for measurement of signals close to DC but also delivers outstanding
> +  performance with input bandwidths out to ~10kHz.
> +
> +  Datasheets for supported chips:
>      https://www.analog.com/media/en/technical-documentation/data-sheets/AD7172-2.pdf
> +    https://www.analog.com/media/en/technical-documentation/data-sheets/AD7172-4.pdf
>      https://www.analog.com/media/en/technical-documentation/data-sheets/AD7173-8.pdf
>      https://www.analog.com/media/en/technical-documentation/data-sheets/AD7175-2.pdf
> +    https://www.analog.com/media/en/technical-documentation/data-sheets/AD7175-8.pdf
>      https://www.analog.com/media/en/technical-documentation/data-sheets/AD7176-2.pdf
> +    https://www.analog.com/media/en/technical-documentation/data-sheets/AD7177-2.pdf
>  
>  properties:
>    compatible:
>      enum:
>        - adi,ad7172-2
> +      - adi,ad7172-4
>        - adi,ad7173-8
>        - adi,ad7175-2
> +      - adi,ad7175-8
>        - adi,ad7176-2
> +      - adi,ad7177-2
>  
>    reg:
>      maxItems: 1
> @@ -89,8 +103,10 @@ patternProperties:
>            refout-avss: REFOUT/AVSS (Internal reference)
>            avdd       : AVDD
>  
> -          External reference refin2 only available on ad7173-8.
> -          If not specified, internal reference used.
> +          External reference refin2 only available on ad7173-8 and ad7172-4.
> +          Internal reference refout-avss not available on ad7172-4.
> +
> +          If not specified, internal reference used (if available).
>          $ref: /schemas/types.yaml#/definitions/string
>          enum:
>            - refin
> @@ -111,12 +127,15 @@ required:
>  allOf:
>    - $ref: /schemas/spi/spi-peripheral-props.yaml#
>  
> +  # Only ad7172-4 and ad7173-8 support refin2
>    - if:
>        properties:
>          compatible:
>            not:
>              contains:
> -              const: adi,ad7173-8
> +              anyOf:
> +                - const: adi,ad7172-4
> +                - const: adi,ad7173-8
>      then:
>        properties:
>          refin2-supply: false
> @@ -129,6 +148,29 @@ allOf:
>                  - refout-avss
>                  - avdd
>  
> +  # Model ad7172-4 does not support internal reference
> +  #  mandatory to have an external reference
> +  - if:
> +      properties:
> +        compatible:
> +          contains:
> +            const: adi,ad7172-4
> +    then:
> +      patternProperties:
> +        "^channel@[0-9a-f]$":
> +          properties:
> +            adi,reference-select:
> +              enum:
> +                - refin
> +                - refin2
> +                - avdd
> +              default: false

The default shouldn't be needed here since the property is required.

> +          required:
> +            - adi,reference-select
> +      oneOf:
> +        - required: [refin2-supply]
> +        - required: [refin-supply]

I'm a little curious - the enum allows avdd but you are requiring one of
these two references to be set. Is one required if avdd is used as the
reference?

Thanks,
Conor.

> +
>  unevaluatedProperties: false
>  
>  examples:
> -- 
> 2.42.0
> 

[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 228 bytes --]

^ permalink raw reply	[flat|nested] 5+ messages in thread

* Re: [PATCH 2/2] iio: adc: ad7173: add support for additional models
  2024-01-15 13:53 ` [PATCH 2/2] iio: " Dumitru Ceclan
@ 2024-01-15 19:52   ` Andy Shevchenko
  0 siblings, 0 replies; 5+ messages in thread
From: Andy Shevchenko @ 2024-01-15 19:52 UTC (permalink / raw)
  To: Dumitru Ceclan
  Cc: linus.walleij, brgl, andy, linux-gpio, Lars-Peter Clausen,
	Jonathan Cameron, Rob Herring, Krzysztof Kozlowski, Conor Dooley,
	Arnd Bergmann, ChiaEn Wu, Niklas Schnelle, Leonard Göhrs,
	Mike Looijmans, Haibo Chen, Hugo Villeneuve, Ceclan Dumitru,
	linux-iio, devicetree, linux-kernel

On Mon, Jan 15, 2024 at 3:54 PM Dumitru Ceclan <mitrutzceclan@gmail.com> wrote:
>
> Add support for Analog Devices AD7172-2, AD7175-8, AD7177-2

Missing period.

...

> + * AD717X family SPI ADC driver

X --> x

...

> + * Suported devices:

Supported

...

> + *  AD7172-2 AD7172-4 AD7173-8 AD7175-2 AD7175-8 AD7176-2 AD7177-2

Too long and no good delimiter (like comma), can you reformat this list?

...

> +#define AD7172_2_ID                    0x00d0
> +#define AD7172_4_ID                    0x2050
>  #define AD7173_ID                      0x30d0
> +#define AD7175_2_ID                    0x0cd0
> +#define AD7175_8_ID                    0x3cd0
>  #define AD7176_ID                      0x0c90
> +#define AD7177_ID                      0x4fd0

Why not order by the ID value?

...

> +               //AD7177-2 has the filter values [0-6] marked as reserved
> +               // datasheet page 58

Be consistent with the type of comments. Either all C++ style or C.
Also missing space in the first line.

...

> +               if (ref_sel == AD7173_SETUP_REF_SEL_INT_REF &&
> +                   st->info->id == AD7172_2_ID){

Missing space.

> +                       fwnode_handle_put(child);
> +                       return dev_err_probe(dev, -EINVAL, "Internal reference is not available on ad7172-2\n");
> +               }

Not sure if Jonathan makes his series in for fwnode handle RAII.

-- 
With Best Regards,
Andy Shevchenko

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2024-01-15 19:52 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2024-01-15 13:53 [PATCH 0/2] Add support for additional AD717X models Dumitru Ceclan
2024-01-15 13:53 ` [PATCH 1/2] dt-bindings: adc: ad7173: add support for additional models Dumitru Ceclan
2024-01-15 16:10   ` Conor Dooley
2024-01-15 13:53 ` [PATCH 2/2] iio: " Dumitru Ceclan
2024-01-15 19:52   ` Andy Shevchenko

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox